@@ -17,6 +17,11 @@ class GetStaticBlock(TemplateTagNode):
             return ''
 
 
+def has_perm(user, codename):
+    model, codename = codename.split('.')
+    return user.has_perm('%ss.%s_%s' % (model, codename, model))
+
 register = template.Library()
 register.tag('get_static_block', GetStaticBlock.process_tag)
 
+register.filter('has_perm', has_perm)
